============================
Toot - a Mastodon CLI client
============================

.. image:: https://raw.githubusercontent.com/ihabunek/toot/master/trumpet.png

Toot is a CLI and TUI tool for interacting with Mastodon instances from the command line.

.. image:: https://img.shields.io/travis/ihabunek/toot.svg?maxAge=3600&style=flat-square
   :target: https://travis-ci.org/ihabunek/toot
.. image:: https://img.shields.io/badge/author-%40ihabunek-blue.svg?maxAge=3600&style=flat-square
   :target: https://mastodon.social/@ihabunek
.. image:: https://img.shields.io/github/license/ihabunek/toot.svg?maxAge=3600&style=flat-square
   :target: https://opensource.org/licenses/MIT
.. image:: https://img.shields.io/pypi/v/toot.svg?maxAge=3600&style=flat-square
   :target: https://pypi.python.org/pypi/toot

Resources
---------

* Homepage: https://github.com/ihabunek/toot
* Issues: https://github.com/ihabunek/toot/issues
* Documentation: https://toot.readthedocs.io/en/latest/
* Discussion and support: #toot IRC channel on freenode.net
  (`webchat <https://webchat.freenode.net/?channels=toot>`_)

Features
--------

* Posting, replying, deleting statuses
* Support for media uploads, spoiler text, sensitive content
* Search by account or hash tag
* Following, muting and blocking accounts
* Simple switching between authenticated in Mastodon accounts

Terminal User Interface
-----------------------

toot includes a curses-based terminal user interface (TUI). Run it with ``toot tui``.

.. image :: https://raw.githubusercontent.com/ihabunek/toot/master/docs/_static/tui_list.png

.. image :: https://raw.githubusercontent.com/ihabunek/toot/master/docs/_static/tui_compose.png


License
-------

Copyright 2018 Ivan Habunek <ivan@habunek.com>

Licensed under `GPLv3 <http://www.gnu.org/licenses/gpl-3.0.html>`_, see `LICENSE <LICENSE>`_.
